searchData={"items":[{"type":"module","title":"Ultraviolet","doc":"Ultraviolet is a color manipulation library designed to work like\n[`chroma-js`](https://github.com/gka/chroma.js). It may not have full parity\nwith `chroma-js`, but it includes most of the common operations and features.\n\nThe first step to get your color into Ultraviolet is to create a\n`Ultraviolet.Color`. This can be done through `new/1`, `new/2`, or the\nconstructors for each supported color space: `hsl/2` for HSL, `hsv/2` for HSV,\netc.","ref":"Ultraviolet.html"},{"type":"module","title":"Getting Started - Ultraviolet","doc":"Here are a few things `Ultraviolet` can do:\n\n- read colors from a wide range of inputs\n- analyze and manipulate colors\n- convert colors into a wide range of formats\n- linear, bezier, and custom interpolation in different color spaces\n\nHere's an example of a simple read / manipulate / output chain:\n\n    iex>{:ok, color} = Ultraviolet.new(\"pink\");\n    iex>color |> Ultraviolet.Color.darken!() |> Ultraviolet.Color.saturate!(2) |> Ultraviolet.Color.hex()\n    \"#ff6d93\"\n\nAside from that, `Ultraviolet` can help you **generate nice colors** using\nvarious methods. These colors can be used, for example, as a color palette for\nmaps or data visualization.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"#fafa6e\", \"#2a4858\"], space: :lch);\n    iex>Enum.map(Ultraviolet.Scale.take(scale, 6), &Ultraviolet.Color.hex/1)\n    [\"#fafa6e\", \"#bed869\", \"#6aba78\", \"#00969d\", \"#1b6c85\", \"#2a4858\"]\n\nThe rest of this module's documentation has more examples.","ref":"Ultraviolet.html#module-getting-started"},{"type":"function","title":"Ultraviolet.average/2","doc":"Similar to `mix/3`, but accepts more than two colors. Simple averaging\nof the R,G,B components and the alpha channel.","ref":"Ultraviolet.html#average/2"},{"type":"function","title":"Examples - Ultraviolet.average/2","doc":"iex> colors = [\"ddd\", \"yellow\", \"red\", \"teal\"];\n    iex>{:ok, color} = Ultraviolet.average(colors);\n    iex>Ultraviolet.Color.hex(color)\n    \"#d3b480\"\n    iex>{:ok, color} = Ultraviolet.average(colors, space: :rgb);\n    iex>Ultraviolet.Color.hex(color)\n    \"#b79757\"\n    iex>{:ok, color} = Ultraviolet.average(colors, space: :lab);\n    iex>Ultraviolet.Color.hex(color)\n    \"#d3a96a\"\n    iex>{:ok, color} = Ultraviolet.average(colors, space: :lch);\n    iex>Ultraviolet.Color.hex(color)\n    \"#ef9e4e\"\n\nAlso works with alpha channels:\n\n    iex>{:ok, color} = Ultraviolet.average([\"red\", %Ultraviolet.Color{r: 0, g: 0, b: 0, a: 0.0}])\n    iex>Ultraviolet.Color.hex(color)\n    \"#b4000080\"\n\nYou can also provide an array of weights to compute a weighted average:\n\n    iex> colors = [\"ddd\", \"yellow\", \"red\", \"teal\"];\n    iex>{:ok, color} = Ultraviolet.average(colors, space: :lch, weights: [1, 1, 2, 1]);\n    iex>Ultraviolet.Color.hex(color)\n    \"#f98841\"\n    iex>{:ok, color} = Ultraviolet.average(colors, space: :lch, weights: [1.5, 0.5, 1, 2.3]);\n    iex>Ultraviolet.Color.hex(color)\n    \"#ae9e52\"","ref":"Ultraviolet.html#average/2-examples"},{"type":"function","title":"Ultraviolet.blend/3","doc":"Blends two colors using RGB channel-wise blend functions.","ref":"Ultraviolet.html#blend/3"},{"type":"function","title":"Valid Blend Modes - Ultraviolet.blend/3","doc":"- `:multiply`\n- `:darken`\n- `:lighten`\n- `:screen`\n- `:overlay`\n- `:burn`\n- `:dodge`","ref":"Ultraviolet.html#blend/3-valid-blend-modes"},{"type":"function","title":"Examples - Ultraviolet.blend/3","doc":"iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :multiply);\n    iex>Ultraviolet.Color.hex(color)\n    \"#47af22\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :darken);\n    iex>Ultraviolet.Color.hex(color)\n    \"#4cbb22\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :lighten);\n    iex>Ultraviolet.Color.hex(color)\n    \"#eeeefc\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :screen);\n    iex>Ultraviolet.Color.hex(color)\n    \"#f3fafc\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :overlay);\n    iex>Ultraviolet.Color.hex(color)\n    \"#e7f643\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :burn);\n    iex>Ultraviolet.Color.hex(color)\n    \"#c6e81f\"\n    iex>{:ok, color} = Ultraviolet.blend(\"4cbbfc\", \"eeee22\", :dodge);\n    iex>Ultraviolet.Color.hex(color)\n    \"#ffffff\"","ref":"Ultraviolet.html#blend/3-examples"},{"type":"function","title":"Ultraviolet.hcl/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.LCH`.\n\nThis is the same as `lch/2`, but with the channel order of the first\nargument reversed.","ref":"Ultraviolet.html#hcl/2"},{"type":"function","title":"Example - Ultraviolet.hcl/2","doc":"iex>Ultraviolet.hcl({130, 40, 80})\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}","ref":"Ultraviolet.html#hcl/2-example"},{"type":"function","title":"Ultraviolet.hsl/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.HSL`.","ref":"Ultraviolet.html#hsl/2"},{"type":"function","title":"Examples - Ultraviolet.hsl/2","doc":"iex>Ultraviolet.hsl({330, 0.5, 1})\n    {:ok, %Ultraviolet.Color{r: 255, g: 255, b: 255, a: 1.0}}\n    iex>Ultraviolet.hsl([330, 0.5, 1, 0.5], round: 1)\n    {:ok, %Ultraviolet.Color{r: 255.0, g: 255.0, b: 255.0, a: 0.5}}","ref":"Ultraviolet.html#hsl/2-examples"},{"type":"function","title":"Ultraviolet.hsv/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.HSV`.","ref":"Ultraviolet.html#hsv/2"},{"type":"function","title":"Examples - Ultraviolet.hsv/2","doc":"iex>Ultraviolet.hsv([330, 0.5, 1])\n    {:ok, %Ultraviolet.Color{r: 255, g: 255, b: 255, a: 1.0}}\n    iex>Ultraviolet.hsv({330, 0.5, 1, 0.5}, round: 1)\n    {:ok, %Ultraviolet.Color{r: 255.0, g: 255.0, b: 255.0, a: 0.5}}","ref":"Ultraviolet.html#hsv/2-examples"},{"type":"function","title":"Ultraviolet.lab/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.Lab`","ref":"Ultraviolet.html#lab/2"},{"type":"function","title":"Colorspace Options - Ultraviolet.lab/2","doc":"- `:reference`: the CIE Lab [white reference point](`t:Ultraviolet.Color.Lab.white_point/0`). Default: `:d65`","ref":"Ultraviolet.html#lab/2-colorspace-options"},{"type":"function","title":"Examples - Ultraviolet.lab/2","doc":"iex>Ultraviolet.lab({50, -20, 50})\n    {:ok, %Ultraviolet.Color{r: 110, g: 127, b: 21, a: 1.0}}\n    iex>Ultraviolet.lab([80, -20, 50], round: 1)\n    {:ok, %Ultraviolet.Color{r: 192.3, g: 206.7, b: 101.7, a: 1.0}}\n    iex>Ultraviolet.lab([80, -20, 50, 0.5], reference: :d50)\n    {:ok, %Ultraviolet.Color{r: 184, g: 208, b: 100, a: 0.5}}","ref":"Ultraviolet.html#lab/2-examples"},{"type":"function","title":"Ultraviolet.lch/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.LCH`.","ref":"Ultraviolet.html#lch/2"},{"type":"function","title":"Colorspace Options - Ultraviolet.lch/2","doc":"- `:reference`: the CIE Lab [white reference point](`t:Ultraviolet.Color.Lab.white_point/0`). Default: `:d65`","ref":"Ultraviolet.html#lch/2-colorspace-options"},{"type":"function","title":"Example - Ultraviolet.lch/2","doc":"iex>Ultraviolet.lch({80, 40, 130})\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}","ref":"Ultraviolet.html#lch/2-example"},{"type":"function","title":"Ultraviolet.mix/3","doc":"Mixes two colors. the mix `ratio` is a value between 0 and 1","ref":"Ultraviolet.html#mix/3"},{"type":"function","title":"Examples - Ultraviolet.mix/3","doc":"iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\");\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#b400b4\"\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.25);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#dd0080\"\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.75);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#8000dd\"\n\nThe color mixing produces different results based on the color space used for\ninterpolation (default: `:lrgb`).\n\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :rgb);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#800080\"\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :hsl);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#ff00ff\"\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :lab);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#ca0089\"\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :lch);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#fa0080\"","ref":"Ultraviolet.html#mix/3-examples"},{"type":"function","title":"Available Spaces - Ultraviolet.mix/3","doc":"- `:lrgb` (Linear RGB)\n- `:rgb`\n- `:hsv`\n- `:hsl`\n- `:lch` and `:oklch`\n- `:hcl`\n- `:lab` and `:oklab`","ref":"Ultraviolet.html#mix/3-available-spaces"},{"type":"function","title":"Long Hue Interpolation - Ultraviolet.mix/3","doc":"Hue-based color spaces will take the \"short\" route between hues by default.\nIf you want your mixture to take the long route instead, set the `longer?`\noption to `true`.\n\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :hsv, longer?: true);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#00ff00\"\n\nKeep in mind this option only applies to color spaces with a Hue channel.\nIf you want to use another color space, `longer?` will have no effect:\n\n    iex>{:ok, mixed} = Ultraviolet.mix(\"red\", \"blue\", ratio: 0.5, space: :lab, longer?: true);\n    iex>Ultraviolet.Color.hex(mixed)\n    \"#ca0089\"","ref":"Ultraviolet.html#mix/3-long-hue-interpolation"},{"type":"function","title":"Ultraviolet.new/1","doc":"Creates a new `Ultraviolet.Color` from the given `input`.","ref":"Ultraviolet.html#new/1"},{"type":"function","title":"Examples - Ultraviolet.new/1","doc":"`new/1` supports a wide variety of inputs:","ref":"Ultraviolet.html#new/1-examples"},{"type":"function","title":"Named colors - Ultraviolet.new/1","doc":"All named colors as defined by the\n[W3CX11 specification](https://en.wikipedia.org/wiki/X11_color_names) are\nsupported:\n\n    iex>Ultraviolet.new(\"hotpink\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 105, b: 180, a: 1.0}}","ref":"Ultraviolet.html#new/1-named-colors"},{"type":"function","title":"Hexadecimal Strings - Ultraviolet.new/1","doc":"If there's no matching named color, check for a hexidecimal string.\nIt ignores case, the `#` sign is optional, and it can recognize the\nshorter 3-letter format.\n\n    iex>Ultraviolet.new(\"#ff3399\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new(\"F39\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}","ref":"Ultraviolet.html#new/1-hexadecimal-strings"},{"type":"function","title":"Hexadecimal Numbers - Ultraviolet.new/1","doc":"Any number between `0` and `16_777_215` will be recognized as a Color:\n\n    iex>Ultraviolet.new(0x000000)\n    {:ok, %Ultraviolet.Color{r: 0, g: 0, b: 0, a: 1.0}}\n    iex>Ultraviolet.new(0xff3399)\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}","ref":"Ultraviolet.html#new/1-hexadecimal-numbers"},{"type":"function","title":"Individual R, G, B, A - Ultraviolet.new/1","doc":"You can also pass RGBA channel values individually in an array or tuple, Each\nchannel must be within `0..255`.\n\n    iex>Ultraviolet.new({0xff, 0x33, 0x99})\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new({255, 51, 153})\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new([255, 51, 153])\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new([255, 51, 153, 0.5])\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 0.5}}","ref":"Ultraviolet.html#new/1-individual-r-g-b-a"},{"type":"function","title":"Ultraviolet.new/2","doc":"Creates a new `Ultraviolet.Color` from the given `input` and `options`.\n\n`new/2` allows a bit more control over the colors you create. You can pass in\ncolorspace-specific options, the `colorspace` you want to use, and other\ntransformation-related options.\n\nSee the colorspace-specific constructors for more details about what options\nare available for each colorspace.\n\nThis also allows for different datatype options, e.g. simple lists and tuples,\nfor the first argument.","ref":"Ultraviolet.html#new/2"},{"type":"function","title":"Generic Options - Ultraviolet.new/2","doc":"These options are available to `new/2` as well as all colorspace-specific\nconstructors:\n\n- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.html#new/2-generic-options"},{"type":"function","title":"Examples - Ultraviolet.new/2","doc":"","ref":"Ultraviolet.html#new/2-examples"},{"type":"function","title":"HSL - Ultraviolet.new/2","doc":"iex>Ultraviolet.new({330, 1, 0.6}, space: :hsl)\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new([330, 1, 0.6, 0.5], space: :hsl)\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 0.5}}","ref":"Ultraviolet.html#new/2-hsl"},{"type":"function","title":"HSV / HSB - Ultraviolet.new/2","doc":"iex>Ultraviolet.new({330, 0.8, 1}, space: :hsv)\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 1.0}}\n    iex>Ultraviolet.new([330, 0.8, 1, 0.5], space: :hsv)\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153, a: 0.5}}","ref":"Ultraviolet.html#new/2-hsv-hsb"},{"type":"function","title":"Lab - Ultraviolet.new/2","doc":"iex>Ultraviolet.new({40, -20, 50}, space: :lab)\n    {:ok, %Ultraviolet.Color{r: 83, g: 102, b: 0, a: 1.0}}\n    iex>Ultraviolet.new([40, -20, 50, 0.5], space: :lab)\n    {:ok, %Ultraviolet.Color{r: 83, g: 102, b: 0, a: 0.5}}","ref":"Ultraviolet.html#new/2-lab"},{"type":"function","title":"LCH / HCL - Ultraviolet.new/2","doc":"iex>Ultraviolet.new({80, 40, 130}, space: :lch)\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}\n    iex>Ultraviolet.new({130, 40, 80, 0.5}, space: :hcl)\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 0.5}}\n    iex>Ultraviolet.new([80, 40, 130], space: :lch)\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}\n    iex>Ultraviolet.new([h: 130, c: 40, l: 80, a: 0.5], space: :hcl)\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 0.5}}","ref":"Ultraviolet.html#new/2-lch-hcl"},{"type":"function","title":"OKLab - Ultraviolet.new/2","doc":"iex>Ultraviolet.new([0.4, -0.2, 0.5], space: :oklab)\n    {:ok, %Ultraviolet.Color{r: 98, g: 68, b: 0, a: 1.0}}\n    iex>Ultraviolet.new({0.4, -0.2, 0.5, 0.5}, space: :oklab)\n    {:ok, %Ultraviolet.Color{r: 98, g: 68, b: 0, a: 0.5}}","ref":"Ultraviolet.html#new/2-oklab"},{"type":"function","title":"OKLCH - Ultraviolet.new/2","doc":"iex>Ultraviolet.new([0.5, 0.2, 240], space: :oklch)\n    {:ok, %Ultraviolet.Color{r: 0, g: 105, b: 199, a: 1.0}}\n    iex>Ultraviolet.new({0.5, 0.2, 240, 0.5}, space: :oklch)\n    {:ok, %Ultraviolet.Color{r: 0, g: 105, b: 199, a: 0.5}}","ref":"Ultraviolet.html#new/2-oklch"},{"type":"function","title":"Ultraviolet.oklab/2","doc":"Generates the sRGB representation of an `Ultraviolet.Color.OKLab`.","ref":"Ultraviolet.html#oklab/2"},{"type":"function","title":"Example - Ultraviolet.oklab/2","doc":"iex>Ultraviolet.oklab({0.5, -0.2, 0.5})\n    {:ok, %Ultraviolet.Color{r: 128, g: 97, b: 0, a: 1.0}}\n    iex>Ultraviolet.oklab([0.8, -0.2, 0.5])\n    {:ok, %Ultraviolet.Color{r: 217, g: 197, b: 0, a: 1.0}}","ref":"Ultraviolet.html#oklab/2-example"},{"type":"function","title":"Ultraviolet.oklch/2","doc":"Generates the sRGB representation of a `Ultraviolet.Color.OKLCH`.","ref":"Ultraviolet.html#oklch/2"},{"type":"function","title":"Example - Ultraviolet.oklch/2","doc":"iex>Ultraviolet.oklch({0.8, 0.12, 60})\n    {:ok, %Ultraviolet.Color{r: 246, g: 171, b: 107, a: 1.0}}","ref":"Ultraviolet.html#oklch/2-example"},{"type":"function","title":"Ultraviolet.scale/0","doc":"Create a new color `Scale` from `\"white\"` to `\"black\"` with default options.\n\nSee `scale/2` for examples.","ref":"Ultraviolet.html#scale/0"},{"type":"function","title":"Ultraviolet.scale/1","doc":"Create a new color `Scale` with the given `colors` and default options.\n\nSee `scale/2` for examples.","ref":"Ultraviolet.html#scale/1"},{"type":"function","title":"Ultraviolet.scale/2","doc":"Creates a new color `Scale` with the given `colors` and `options`.\n\nColor scales, created with `scale/2`, map numbers onto a color\npalette. Because they're basically lazy maps, they have similar access\nfunctions as maps, as well as some Enumerable:\n\n- `Ultraviolet.Scale.get/3` to get a single color\n- `Ultraviolet.Scale.fetch/2` to fetch a single color\n- `Ultraviolet.Scale.take/2` or `Ultraviolet.Scale.take_keys/2` to get several colors at once\n\nTo see other access functions, see the `Ultraviolet.Scale` documentation.\n\nBy default, a scale has the domain `[0, 1]` and a range of `\"white\"` to\n`\"black\"`:\n\n    iex>{:ok, scale} = Ultraviolet.scale();\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(scale, 0.25);\n    iex>Ultraviolet.Color.hex(color)\n    \"#bfbfbf\"\n\nThe first argument is an array of colors. Any color that can be read by\n`Ultraviolet.new/1` works here too. If you pass more than two colors, they\nwill be evenly distributed along the gradient.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"008ae5\"]);\n    iex>Ultraviolet.Scale.take_keys(scale, [0, 1])\n    [\n      %Ultraviolet.Color{r: 255, g: 255, b: 0},\n      %Ultraviolet.Color{r: 0, g: 138, b: 229},\n    ]\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"red\", \"black\"]);\n    iex>Ultraviolet.Scale.take_keys(scale, [0, 0.5, 1])\n    [\n      %Ultraviolet.Color{r: 255, g: 255, b: 0},\n      %Ultraviolet.Color{r: 255, g: 0, b: 0},\n      %Ultraviolet.Color{r: 0, g: 0, b: 0},\n    ]","ref":"Ultraviolet.html#scale/2"},{"type":"function","title":"Color Brewer - Ultraviolet.scale/2","doc":"Ultraviolet includes the definitions from\n[ColorBrewer](https://colorbrewer2.org) as well.\n\n    iex>{:ok, scale} = Ultraviolet.scale(\"OrRd\");\n    iex>Enum.map(Ultraviolet.Scale.take(scale, 5), &Ultraviolet.Color.hex/1)\n    [\"#fff7ec\", \"#fdd49e\", \"#fc8d59\", \"#d7301f\", \"#7f0000\"]\n\nYou can reverse the colors by reversing the domain:\n\n    iex>{:ok, scale} = Ultraviolet.scale(\"YlGnBu\", domain: [1, 0]);\n    iex>Ultraviolet.Scale.fetch(scale, 0.25)\n    {:ok, %Ultraviolet.Color{r: 34, g: 94, b: 168}}","ref":"Ultraviolet.html#scale/2-color-brewer"},{"type":"function","title":"Color Count - Ultraviolet.scale/2","doc":"You can include a `:count` option when creating a ColorBrewer-based scale\nto retrieve the Color Brewer palette with the given number of colors.\nThe default is `9`.\n\n    iex>{:ok, scale} = Ultraviolet.scale(\"YlGnBu\", count: 5);\n    iex> scale.colors\n    [\n      %Ultraviolet.Color{r: 255, g: 255, b: 204, a: 1.0},\n      %Ultraviolet.Color{r: 161, g: 218, b: 180, a: 1.0},\n      %Ultraviolet.Color{r: 65, g: 182, b: 196, a: 1.0},\n      %Ultraviolet.Color{r: 44, g: 127, b: 184, a: 1.0},\n      %Ultraviolet.Color{r: 37, g: 52, b: 148, a: 1.0}\n    ]","ref":"Ultraviolet.html#scale/2-color-count"},{"type":"function","title":"Options - Ultraviolet.scale/2","doc":"Scales can be created with a number of options which affect the output colors:","ref":"Ultraviolet.html#scale/2-options"},{"type":"function","title":"Domain - Ultraviolet.scale/2","doc":"You can change the input domain to match your use case. The default domain is\n`[0, 1]`.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"008ae5\"], domain: [0, 100]);\n    iex>Enum.map(Ultraviolet.Scale.take_keys(scale, [0, 100]), &Ultraviolet.Color.hex/1)\n    [\"#ffff00\", \"#008ae5\"]\n\nYou can use this option to set the exact positions of each color:\n\n    iex>{:ok, scale} = Ultraviolet.scale(\n    ...>  [\"yellow\", \"lightgreen\", \"008ae5\"],\n    ...>  domain: [0, 0.25, 1]\n    ...>);\n    iex>Enum.map(Ultraviolet.Scale.take_keys(scale, [0, 0.25, 1]), &Ultraviolet.Color.hex/1)\n    [\"#ffff00\", \"#90ee90\", \"#008ae5\"]","ref":"Ultraviolet.html#scale/2-domain"},{"type":"function","title":"Color Space - Ultraviolet.scale/2","doc":"As with `mix/3`, the result of color interpolation will depend on the color\nspace in which the channels are interpolated. The default `:space` is `:rgb`.\n\nThis default is okay, but sometimes, two-color RGB gradients go through a gray\n\"dead zone\", which...doesn't look great. Other color spaces can produce better\nresults.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"navy\"]);\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(scale, 0.6);\n    iex>Ultraviolet.Color.hex(color)\n    # this is mostly gray\n    \"#66664d\"\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"navy\"], space: :lab);\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(scale, 0.6);\n    iex>Ultraviolet.Color.hex(color)\n    # this is better\n    \"#8e6271\"\n\nThe available values for this option are the same as with `mix/3`.","ref":"Ultraviolet.html#scale/2-color-space"},{"type":"function","title":"Gamma Correction - Ultraviolet.scale/2","doc":"`:gamma` can be used to \"shift\" a scale's center more towards the beginning\n(`:gamma` < 1) or the end (`:gamma` > 1). This option is typically used to\n\"even out\" the lightness gradient. The default gamma is `1`.\n\n    iex>{:ok, _scale} = Ultraviolet.scale([\"yellow\", \"green\"], gamma: 0.5);\n    iex>{:ok, _scale} = Ultraviolet.scale([\"yellow\", \"green\"], gamma: 1);\n    iex>{:ok, _scale} = Ultraviolet.scale([\"yellow\", \"green\"], gamma: 2);","ref":"Ultraviolet.html#scale/2-gamma-correction"},{"type":"function","title":"Lightness Correction - Ultraviolet.scale/2","doc":"`:correct_lightness?` makes sure the lightness range is spread evenly across a\ncolor scale. This option is especially useful when working with multi-hue\ncolor scales. where simple gamma correction won't help very much. The default\nvalue is `false`, i.e. lightness correction turned off.\n\n    iex>{:ok, scale} = Ultraviolet.scale(\n    ...>  [\"black\", \"red\", \"yellow\", \"white\"]\n    ...>);\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(scale, 0.67);\n    iex>Ultraviolet.Color.hex(color)\n    \"#ffff03\"\n    iex>{:ok, corrected_scale} = Ultraviolet.scale(\n    ...>  [\"black\", \"red\", \"yellow\", \"white\"],\n    ...>  correct_lightness?: true\n    ...>);\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(corrected_scale, 0.67);\n    iex>Ultraviolet.Color.hex(color)\n    \"#ff8000\"","ref":"Ultraviolet.html#scale/2-lightness-correction"},{"type":"function","title":"Padding - Ultraviolet.scale/2","doc":"`:padding` reduces the color range by cutting off a fraction of the gradient\non both sides. If you pass a single number, the same padding will be applied\nto both sides. The default padding is `0`, i.e. no padding applied.\n\n    iex>{:ok, _scale} = Ultraviolet.scale(\n    ...>  [\"red\", \"yellow\", \"blue\"],\n    ...>  padding: 0.15\n    ...>);\n\nAlternatively, you can specify the padding for each side individually by\npassing a two-number tuple:\n\n    iex>{:ok, _scale} = Ultraviolet.scale(\n    ...>  [\"red\", \"yellow\", \"blue\"],\n    ...>  padding: {0.2, 0}\n    ...>);","ref":"Ultraviolet.html#scale/2-padding"},{"type":"function","title":"Classes - Ultraviolet.scale/2","doc":"If you want the scale to return a distinct set of colors instead of a\ncontinuous gradient, you can use the `:classes` option. Passing an integer\nwill break up the scale into equidistant classes. \n\n    iex>{:ok, scale} = Ultraviolet.scale(\"OrRd\", classes: 5);\n    iex>Enum.map(Ultraviolet.Scale.take_keys(scale, [0.1, 0.15]), &Ultraviolet.Color.hex/1)\n    [\"#fff7ec\", \"#fff7ec\"]\n\nYou can also define custom class breaks by passing them as an array.\n\n    iex>{:ok, scale} = Ultraviolet.scale(\n    ...>  \"OrRd\",\n    ...>  classes: [0, 0.3, 0.55, 0.85, 1]\n    ...>);\n    iex>Enum.map(Ultraviolet.Scale.take_keys(scale, [0.15, 0.25]), &Ultraviolet.Color.hex/1)\n    [\"#fff7ec\", \"#fff7ec\"]\n\nThe default value is `0`, meaning a continuous gradient will be used.","ref":"Ultraviolet.html#scale/2-classes"},{"type":"function","title":"Interpolation - Ultraviolet.scale/2","doc":"By default, the colors retrieved from the scale are the result of linear\ninterpolation. If you want to change this, use the `:interpolation` option.\n\nThis option accepts a unary function (i.e. a function with one argument),\nwhich will be called every time a color retrieval function is called on that\nspace. It should accept a number and return a `Ultraviolet.Color` or an\n`{:ok, Ultraviolet.Color}` tuple.\n\nThere are also two builtin interpolation options: `:linear` for linear\ninterpolation (the default) and `:bezier` for Bezier interpolation. For\n`:bezier` interpolation, the `:space` must be either `:lab` or `:oklab`.\nIf no `:space` option is passed, `:lab` will be used.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"red\", \"black\"]);\n    iex>Enum.map(Ultraviolet.Scale.take(scale, 5), &Ultraviolet.Color.hex/1)\n    [\"#ffff00\", \"#ff8000\", \"#ff0000\", \"#800000\", \"#000000\"]\n    iex>Ultraviolet.scale(\n    ...>  [\"yellow\", \"red\", \"black\"],\n    ...>  interpolation: :bezier,\n    ...>  space: :rgb\n    ...>)\n    {:error, \"bezier interpolation requires either Lab or OKLab colorspace\"}\n    iex>{:ok, bezier_scale} = Ultraviolet.scale(\n    ...>  [\"yellow\", \"red\", \"black\"],\n    ...>  interpolation: :bezier\n    ...>);\n    iex>Enum.map(Ultraviolet.Scale.take(bezier_scale, 5), &Ultraviolet.Color.hex/1)\n    [\"#ffff00\", \"#f5a900\", \"#bf5e0b\", \"#6c280e\", \"#000000\"]\n\n#### Example: `cubehelix`\n\nHere's how you might use this option to implement Dave Green's\n[cubehelix scheme](https://people.phy.cam.ac.uk/dag9/CUBEHELIX/):\n\n    iex>defmodule CubeHelix do\n    ...>  def interpolate(x, params) do\n    ...>    a = :math.tau() * ((params.start + 120) / 360 + params.rotations * x)\n    ...>    l = :math.pow(lightness(params) + dl(params) * x, params.gamma)\n    ...>    h = hue(params, x)\n    ...>    amp = (h * l * (1 - l)) / 2\n    ...>    cos_a = :math.cos(a)\n    ...>    sin_a = :math.sin(a)\n    ...>    [\n    ...>      l + amp * (-0.14861 * cos_a + 1.78277 * sin_a),\n    ...>      l + amp * (-0.29277 * cos_a - 0.90649 * sin_a),\n    ...>      l + amp * (1.97294 * cos_a)\n    ...>    ]\n    ...>    |> Enum.map(&clamp_byte(&1 * 255))\n    ...>    |> Ultraviolet.Color.new()\n    ...>  end\n    ...>\n    ...>  defp lightness(%{lightness: {l0, _}}), do: l0\n    ...>  defp lightness(%{lightness: l}), do: l\n    ...>\n    ...>  defp dl(%{lightness: {l0, l1}}), do: l1 - l0\n    ...>  defp dl(%{lightness: _}), do: 0\n    ...>\n    ...>  defp hue(%{hue: {h0, h1}}, x), do: h0 + x * (h1 - h0)\n    ...>  defp hue(%{hue: hue}, _x), do: hue\n    ...>\n    ...>  defp clamp_byte(n), do: min(max(n, 0), 255)\n    ...>end;\n    iex>params = %{start: 300, rotations: -1.5, hue: 1, gamma: 1, lightness: {0, 1}};\n    iex>{:ok, cubehelix} = Ultraviolet.scale(\n    ...>  [\"black\", \"white\"],\n    ...>  domain: [0, 1],\n    ...>  interpolation: fn x -> CubeHelix.interpolate(x, params) end\n    ...>);\n    iex>Enum.map(Ultraviolet.Scale.take(cubehelix, 5), &Ultraviolet.Color.hex/1)\n    [\"#000000\", \"#16534c\", \"#a07949\", \"#c7b3ed\", \"#ffffff\"]","ref":"Ultraviolet.html#scale/2-interpolation"},{"type":"function","title":"Linear Interpolation: Hue Interpolation Direction - Ultraviolet.scale/2","doc":"As with `mix/3`, use the `:longer?` option when creating a `Scale` to\ninterpolate along the \"longer\" route between hues. See `mix/3` for more\ndetails about how this works.\n\n    iex>{:ok, scale} = Ultraviolet.scale([\"red\", \"lime\"], space: :hsl, longer?: true);\n    iex>Ultraviolet.Color.hex(Ultraviolet.Scale.get(scale, 0.5))\n    \"#0000ff\"","ref":"Ultraviolet.html#scale/2-linear-interpolation-hue-interpolation-direction"},{"type":"function","title":"Ultraviolet.temperature/1","doc":"Converts a temperature into a color, based on the color temperature scale.","ref":"Ultraviolet.html#temperature/1"},{"type":"function","title":"Examples - Ultraviolet.temperature/1","doc":"iex>Ultraviolet.temperature(2000)\n    {:ok, %Ultraviolet.Color{r: 255, g: 139, b: 20, a: 1.0}}\n    iex>Ultraviolet.temperature(3500)\n    {:ok, %Ultraviolet.Color{r: 255, g: 195, b: 138, a: 1.0}}\n    iex>Ultraviolet.temperature(6500)\n    {:ok, %Ultraviolet.Color{r: 255, g: 250, b: 254, a: 1.0}}","ref":"Ultraviolet.html#temperature/1-examples"},{"type":"module","title":"Ultraviolet.Color","doc":"functions related to parsing and generating Color structs for use elsewhere\nin Ultraviolet.","ref":"Ultraviolet.Color.html"},{"type":"module","title":"Color Spaces - Ultraviolet.Color","doc":"Colors, by default, are stored in sRGB representation, but supports other\ncolor spaces as input to `new/4` and `new/5`, where the last parameter is the\ncolor space to translate from.","ref":"Ultraviolet.Color.html#module-color-spaces"},{"type":"module","title":"Available Spaces - Ultraviolet.Color","doc":"- sRGB (the default): `:rgb`\n- HSL: `:hsl`\n- HSV / HSV: `:hsv`\n- CIE Lab: `:lab`\n- LCH: `:lch`, `:hcl`\n- OKLab: `:oklab`\n- OKLCH: `:oklch`","ref":"Ultraviolet.Color.html#module-available-spaces"},{"type":"module","title":"Other Scales - Ultraviolet.Color","doc":"I may add these based on need in the future:\n\n- GL (RGBA normalized to `0..1`)\n- CMYK","ref":"Ultraviolet.Color.html#module-other-scales"},{"type":"function","title":"Ultraviolet.Color.alpha/1","doc":"Get the color opacity.","ref":"Ultraviolet.Color.html#alpha/1"},{"type":"function","title":"Examples - Ultraviolet.Color.alpha/1","doc":"iex> {:ok, color} = Color.new(\"red\");\n    iex> Color.alpha(color)\n    1.0","ref":"Ultraviolet.Color.html#alpha/1-examples"},{"type":"function","title":"Ultraviolet.Color.alpha/2","doc":"Set the color opacity.","ref":"Ultraviolet.Color.html#alpha/2"},{"type":"function","title":"Examples - Ultraviolet.Color.alpha/2","doc":"iex> {:ok, color} = Color.new(\"red\");\n    iex> Color.alpha(color, 0.5)\n    %Color{r: 255, g: 0, b: 0, a: 0.5}","ref":"Ultraviolet.Color.html#alpha/2-examples"},{"type":"function","title":"Ultraviolet.Color.average/3","doc":"Mixes several colors. If `weights` are given, a weighted average is\ncalculated; the number of `weights` must equal the number of colors.\n\nSee `Ultraviolet.average/2` for documentation and examples.","ref":"Ultraviolet.Color.html#average/3"},{"type":"function","title":"Ultraviolet.Color.blend/3","doc":"Blends two colors using RGB channel-wise blend functions. See\n`Ultraviolet.blend/3` for examples and valid blend spaces.","ref":"Ultraviolet.Color.html#blend/3"},{"type":"function","title":"Ultraviolet.Color.brighten!/2","doc":"Brighten a color.","ref":"Ultraviolet.Color.html#brighten!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.brighten!/2","doc":"iex> {:ok, color} = Color.new(\"hotpink\");\n    iex> Color.hex(Color.brighten!(color))\n    \"#ff9ce6\"\n    iex> Color.hex(Color.brighten!(color, 2))\n    \"#ffd1ff\"\n    iex> Color.hex(Color.brighten!(color, 3))\n    \"#ffffff\"","ref":"Ultraviolet.Color.html#brighten!/2-examples"},{"type":"function","title":"Ultraviolet.Color.css/1","doc":"Returns the CSS representation of an RGB color","ref":"Ultraviolet.Color.html#css/1"},{"type":"function","title":"Examples - Ultraviolet.Color.css/1","doc":"iex>Color.css(%Color{})\n    \"rgb(0 0 0)\"\n    iex>Color.css(%Color{r: 255})\n    \"rgb(255 0 0)\"\n    iex>Color.css(%Color{r: 255, a: 0.5})\n    \"rgb(255 0 0 / 0.5)\"","ref":"Ultraviolet.Color.html#css/1-examples"},{"type":"function","title":"Ultraviolet.Color.darken!/2","doc":"Darken a color.","ref":"Ultraviolet.Color.html#darken!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.darken!/2","doc":"iex> {:ok, color} = Color.new(\"hotpink\");\n    iex> Color.hex(Color.darken!(color))\n    \"#c93384\"\n    iex> Color.hex(Color.darken!(color, 2))\n    \"#940058\"\n    iex> Color.hex(Color.darken!(color, 2.6))\n    \"#74003f\"","ref":"Ultraviolet.Color.html#darken!/2-examples"},{"type":"function","title":"Ultraviolet.Color.desaturate!/2","doc":"Decreases the saturation of a color by manipulating the Lch chromaticity.","ref":"Ultraviolet.Color.html#desaturate!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.desaturate!/2","doc":"iex> {:ok, color} = Color.new(\"hotpink\");\n    iex> Color.hex(Color.desaturate!(color))\n    \"#e77dae\"\n    iex> Color.hex(Color.desaturate!(color, 2))\n    \"#cd8ca8\"\n    iex> Color.hex(Color.desaturate!(color, 3))\n    \"#b199a3\"","ref":"Ultraviolet.Color.html#desaturate!/2-examples"},{"type":"function","title":"Ultraviolet.Color.hex/1","doc":"Returns the hexadecimal representation of an RGB color.","ref":"Ultraviolet.Color.html#hex/1"},{"type":"function","title":"Examples - Ultraviolet.Color.hex/1","doc":"iex>Color.hex(%Color{})\n    \"#000000\"\n    iex>Color.hex(%Color{r: 255})\n    \"#ff0000\"\n    iex>Color.hex(%Color{r: 255, a: 0.5})\n    \"#ff000080\"\n\nYou can also use `to_string` to output this value\n\n    iex>to_string(%Color{r: 255, a: 0.5})\n    \"#ff000080\"","ref":"Ultraviolet.Color.html#hex/1-examples"},{"type":"function","title":"Ultraviolet.Color.into/3","doc":"Converts a Color to a different colorspace.","ref":"Ultraviolet.Color.html#into/3"},{"type":"function","title":"Examples - Ultraviolet.Color.into/3","doc":"","ref":"Ultraviolet.Color.html#into/3-examples"},{"type":"function","title":"HSL - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"#ff3399\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153}}\n    iex> Ultraviolet.Color.into(color, :hsl)\n    {:ok, %Ultraviolet.Color.HSL{h: 330, s: 1.0, l: 0.6}}","ref":"Ultraviolet.Color.html#into/3-hsl"},{"type":"function","title":"HSV / HSB - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"#ff3399\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 51, b: 153}}\n    iex> Ultraviolet.Color.into(color, :hsv)\n    {:ok, %Ultraviolet.Color.HSV{h: 330, s: 0.8, v: 1.0}}","ref":"Ultraviolet.Color.html#into/3-hsv-hsb"},{"type":"function","title":"Lab - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"hotpink\")\n    {:ok, %Ultraviolet.Color{r: 255, g: 105, b: 180}}\n    iex> Ultraviolet.Color.into(color, :lab)\n    {:ok, %Ultraviolet.Color.Lab{l_: 65.49, a_: 64.24, b_: -10.65}}\n    iex> Ultraviolet.Color.into(color, :lab, reference: :f2)\n    {:ok, %Ultraviolet.Color.Lab{l_: 66.28, a_: 61.45, b_: -8.62}}\n    # try going the other way now\n    iex> Ultraviolet.new({66.28, 61.45, -8.62, 1.0}, space: :lab, reference: :f2)\n    {:ok, %Ultraviolet.Color{r: 255, g: 105, b: 180}}\n    iex> Ultraviolet.new(%{l_: 66.28, a_: 61.45, b_: -8.62}, space: :lab, reference: :f2)\n    {:ok, %Ultraviolet.Color{r: 255, g: 105, b: 180}}\n    iex> Ultraviolet.new({65.49, 64.24, -10.65, 1.0}, space: :lab)\n    {:ok, %Ultraviolet.Color{r: 255, g: 105, b: 180}}","ref":"Ultraviolet.Color.html#into/3-lab"},{"type":"function","title":"LCH / HCL - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"#aad28c\")\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}\n    iex> Ultraviolet.Color.into(color, :lch, round: 0)\n    {:ok, %Ultraviolet.Color.LCH{l: 80, c: 40, h: 130}}\n    iex> Ultraviolet.Color.into(color, :hcl, round: 0)\n    {:ok, %Ultraviolet.Color.LCH{l: 80, c: 40, h: 130}}","ref":"Ultraviolet.Color.html#into/3-lch-hcl"},{"type":"function","title":"OKLab - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"#d9c500\")\n    {:ok, %Ultraviolet.Color{r: 217, g: 197, b: 0, a: 1.0}}\n    iex> Ultraviolet.Color.into(color, :oklab, round: 2)\n    {:ok, %Ultraviolet.Color.OKLab{l_: 0.81, a_: -0.04, b_: 0.17}}","ref":"Ultraviolet.Color.html#into/3-oklab"},{"type":"function","title":"OKLCH - Ultraviolet.Color.into/3","doc":"iex>{:ok, color} = Ultraviolet.Color.new(\"#aad28c\")\n    {:ok, %Ultraviolet.Color{r: 170, g: 210, b: 140, a: 1.0}}\n    iex> Ultraviolet.Color.into(color, :oklch, round: 0)\n    {:ok, %Ultraviolet.Color.OKLCH{l: 1, c: 0, h: 132}}\n    iex> Ultraviolet.Color.into(color, :oklch, round: 1)\n    {:ok, %Ultraviolet.Color.OKLCH{l: 0.8, c: 0.1, h: 132.5}}","ref":"Ultraviolet.Color.html#into/3-oklch"},{"type":"function","title":"Ultraviolet.Color.mix/3","doc":"Mixes two colors. The mix `weight` is a value between 0 and 1.\n\nSee `Ultraviolet.mix/3` for documentation and examples.","ref":"Ultraviolet.Color.html#mix/3"},{"type":"function","title":"Ultraviolet.Color.new/1","doc":"Generates a `Color` from a hex string, W3CX11 specification color name,\ninteger, or channel tuple/map/list/keyword list.\n\nSee `Ultraviolet.new/1` for more details.","ref":"Ultraviolet.Color.html#new/1"},{"type":"function","title":"Ultraviolet.Color.new/2","doc":"Creates a new `Color` from the given `channels` and `options`.\n\nSee `Ultraviolet.new/2` for more details.","ref":"Ultraviolet.Color.html#new/2"},{"type":"function","title":"Ultraviolet.Color.saturate!/2","doc":"Increases the saturation of a color by manipulating the Lch chromaticity.","ref":"Ultraviolet.Color.html#saturate!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.saturate!/2","doc":"iex> {:ok, color} = Color.new(\"slategray\");\n    iex> Color.hex(Color.saturate!(color))\n    \"#4b83ae\"\n    iex> Color.hex(Color.saturate!(color, 2))\n    \"#0087cd\"\n    iex> Color.hex(Color.saturate!(color, 3))\n    \"#008bec\"","ref":"Ultraviolet.Color.html#saturate!/2-examples"},{"type":"function","title":"Ultraviolet.Color.shade!/2","doc":"Produces a shade of the given color. This is syntactic sugar for `mix/4`\nwith a target color of `black`.","ref":"Ultraviolet.Color.html#shade!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.shade!/2","doc":"iex>{:ok, color} = Color.new(\"hotpink\");\n    iex> Color.hex(Color.shade!(color, ratio: 0.25))\n    \"#dd5b9c\"\n    iex> Color.hex(Color.shade!(color, ratio: 0.5))\n    \"#b44a7f\"\n    iex> Color.hex(Color.shade!(color, ratio: 0.75))\n    \"#80355a\"","ref":"Ultraviolet.Color.html#shade!/2-examples"},{"type":"function","title":"Ultraviolet.Color.temperature/1","doc":"Estimates the temperature of a given color, though this only makes sense for\ncolors from the temperature gradient.","ref":"Ultraviolet.Color.html#temperature/1"},{"type":"function","title":"Examples - Ultraviolet.Color.temperature/1","doc":"iex> {:ok, color} = Color.new(\"#ff3300\");\n    iex> Color.temperature(color)\n    1000\n    iex> {:ok, color} = Color.new(\"#ff8a13\");\n    iex> Color.temperature(color)\n    2000\n    iex> {:ok, color} = Color.new(\"#ffe3cd\");\n    iex> Color.temperature(color)\n    4985\n    iex> {:ok, color} = Color.new(\"#cbdbff\");\n    iex> Color.temperature(color)\n    10049\n    iex> {:ok, color} = Color.new(\"#b3ccff\");\n    iex> Color.temperature(color)\n    15005","ref":"Ultraviolet.Color.html#temperature/1-examples"},{"type":"function","title":"Ultraviolet.Color.tint!/2","doc":"Produces a tint of the given color. This is syntactic sugar for `mix/4`\nwith a target color of `white`.","ref":"Ultraviolet.Color.html#tint!/2"},{"type":"function","title":"Examples - Ultraviolet.Color.tint!/2","doc":"iex>{:ok, color} = Color.new(\"hotpink\");\n    iex> Color.hex(Color.tint!(color, ratio: 0.25))\n    \"#ff9dc9\"\n    iex> Color.hex(Color.tint!(color, ratio: 0.5))\n    \"#ffc3dd\"\n    iex> Color.hex(Color.tint!(color, ratio: 0.75))\n    \"#ffe3ee\"","ref":"Ultraviolet.Color.html#tint!/2-examples"},{"type":"type","title":"Ultraviolet.Color.blend_mode/0","doc":"Blend Modes for use with `blend/2` or `blend/3`","ref":"Ultraviolet.Color.html#t:blend_mode/0"},{"type":"type","title":"Ultraviolet.Color.channels/0","doc":"Generic channel input for a color creation function.","ref":"Ultraviolet.Color.html#t:channels/0"},{"type":"type","title":"Ultraviolet.Color.input/0","doc":"Generic input for a color creation function.","ref":"Ultraviolet.Color.html#t:input/0"},{"type":"type","title":"Ultraviolet.Color.space/0","doc":"The available color spaces for transformation, interpolation, and scales.","ref":"Ultraviolet.Color.html#t:space/0"},{"type":"type","title":"Ultraviolet.Color.space_t/0","doc":"","ref":"Ultraviolet.Color.html#t:space_t/0"},{"type":"type","title":"Ultraviolet.Color.t/0","doc":"Defines the channels in an sRGB color.\n\nThis is the core Ultraviolet structure. See `Ultraviolet` for examples\nof how it can be used.","ref":"Ultraviolet.Color.html#t:t/0"},{"type":"module","title":"Ultraviolet.ColorBrewer","doc":"ColorBrewer colors for Ultraviolet.\n\nThis module requires the optional `:json` dependency. If you don't include it,\nany call to `colors/2` will return `{:error, :not_found}`.","ref":"Ultraviolet.ColorBrewer.html"},{"type":"module","title":"License - Ultraviolet.ColorBrewer","doc":"```\nCopyright (c) 2002 Cynthia Brewer, Mark Harrower, and The Pennsylvania State\nUniversity.\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not\nuse this file except in compliance with the License. You may obtain a copy of\nthe License at\n\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS, WITHOUT\nWARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\nLicense for the specific language governing permissions and limitations under\nthe License.\n```","ref":"Ultraviolet.ColorBrewer.html#module-license"},{"type":"function","title":"Ultraviolet.ColorBrewer.colors/2","doc":"Retrieves the colorbrewer colors associated with the given name.\n\n    iex>Ultraviolet.ColorBrewer.colors(\"Spectral\")\n    {:ok,\n     [\n       %Ultraviolet.Color{r: 213, g: 62, b: 79, a: 1.0},\n       %Ultraviolet.Color{r: 244, g: 109, b: 67, a: 1.0},\n       %Ultraviolet.Color{r: 253, g: 174, b: 97, a: 1.0},\n       %Ultraviolet.Color{r: 254, g: 224, b: 139, a: 1.0},\n       %Ultraviolet.Color{r: 255, g: 255, b: 191, a: 1.0},\n       %Ultraviolet.Color{r: 230, g: 245, b: 152, a: 1.0},\n       %Ultraviolet.Color{r: 171, g: 221, b: 164, a: 1.0},\n       %Ultraviolet.Color{r: 102, g: 194, b: 165, a: 1.0},\n       %Ultraviolet.Color{r: 50, g: 136, b: 189, a: 1.0}\n     ]}\n\nYou can also pass in an optional second argument to return a set number of\ncolors for a given colorbrewer palette:\n\n    iex>Ultraviolet.ColorBrewer.colors(\"Spectral\", 3)\n    {:ok,\n     [\n       %Ultraviolet.Color{r: 252, g: 141, b: 89, a: 1.0},\n       %Ultraviolet.Color{r: 255, g: 255, b: 191, a: 1.0},\n       %Ultraviolet.Color{r: 153, g: 213, b: 148, a: 1.0}\n     ]}\n\nUnknown color palettes, or if you pass in an invalid color count for a given\npalette, will return an error tuple.\n\n    iex>Ultraviolet.ColorBrewer.colors(\"Accent\", 9)\n    {:error, :not_found}\n    iex>Ultraviolet.ColorBrewer.colors(\"Set3\", -1)\n    {:error, :not_found}\n    iex>Ultraviolet.ColorBrewer.colors(\"UnknownPalette\", 5)\n    {:error, :not_found}\n\n**Note**: This function requires the `:jason` optional dependency to use. If\n`Jason` is not installed, all calls to `colors/1` or `colors/2` will return\nan error tuple.","ref":"Ultraviolet.ColorBrewer.html#colors/2"},{"type":"module","title":"Ultraviolet.Scale","doc":"Function related to creating and using color scales.\n\nColor scales are essentually functions that map numbers to a color palette.","ref":"Ultraviolet.Scale.html"},{"type":"function","title":"Ultraviolet.Scale.fetch/2","doc":"Retrieves a single color from the `scale` at the given `value` in the domain.","ref":"Ultraviolet.Scale.html#fetch/2"},{"type":"function","title":"Example - Ultraviolet.Scale.fetch/2","doc":"iex>{:ok, scale} = Ultraviolet.scale();\n    iex>{:ok, color} = Ultraviolet.Scale.fetch(scale, 0.25);\n    iex>Ultraviolet.Color.hex(color)\n    \"#bfbfbf\"","ref":"Ultraviolet.Scale.html#fetch/2-example"},{"type":"function","title":"Ultraviolet.Scale.get/3","doc":"Retrieves a single color from the scale at the given value in the domain.\nIf the given value is invalid, returns the `default` color. If the given value\nis outside of the domain, returns the closest domain bound, i.e. the highest\nor lowest value in the domain.","ref":"Ultraviolet.Scale.html#get/3"},{"type":"function","title":"Example - Ultraviolet.Scale.get/3","doc":"iex>{:ok, scale} = Ultraviolet.scale();\n    iex>Ultraviolet.Color.hex(Ultraviolet.Scale.get(scale, 0.25))\n    \"#bfbfbf\"","ref":"Ultraviolet.Scale.html#get/3-example"},{"type":"function","title":"Ultraviolet.Scale.new/2","doc":"Creates a new color scale. See `Ultraviolet.scale/2` for details about\ncreating scales.","ref":"Ultraviolet.Scale.html#new/2"},{"type":"function","title":"Ultraviolet.Scale.take/2","doc":"Returns a list of `n` equi-distant colors from the `scale`.","ref":"Ultraviolet.Scale.html#take/2"},{"type":"function","title":"Example - Ultraviolet.Scale.take/2","doc":"iex>{:ok, scale} = Ultraviolet.scale(\"OrRd\");\n    iex>Enum.map(Ultraviolet.Scale.take(scale, 5), &Ultraviolet.Color.hex/1)\n    [\"#fff7ec\", \"#fdd49e\", \"#fc8d59\", \"#d7301f\", \"#7f0000\"]","ref":"Ultraviolet.Scale.html#take/2-example"},{"type":"function","title":"Ultraviolet.Scale.take_keys/2","doc":"Returns a list of colors that correspond to each value in `xs`. in `xs`. If\n`xs` contains values that are not within the `scale`'s domain, they are\nclipped to the domain bounds.","ref":"Ultraviolet.Scale.html#take_keys/2"},{"type":"function","title":"Example - Ultraviolet.Scale.take_keys/2","doc":"iex>{:ok, scale} = Ultraviolet.scale([\"yellow\", \"008ae5\"]);\n    iex>Ultraviolet.Scale.take_keys(scale, [0, 1])\n    [\n      %Ultraviolet.Color{r: 255, g: 255, b: 0},\n      %Ultraviolet.Color{r: 0, g: 138, b: 229},\n    ]","ref":"Ultraviolet.Scale.html#take_keys/2-example"},{"type":"type","title":"Ultraviolet.Scale.t/0","doc":"","ref":"Ultraviolet.Scale.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.HSL","doc":"Functions for working in the HSL color space.","ref":"Ultraviolet.Color.HSL.html"},{"type":"function","title":"Ultraviolet.Color.HSL.from_rgb/2","doc":"Converts a Color to HSL\n\nconversion taken from https://wikipedia.org/wiki/HSL_color_space","ref":"Ultraviolet.Color.HSL.html#from_rgb/2"},{"type":"function","title":"Ultraviolet.Color.HSL.new/1","doc":"Generates a new HSL color object\n\n    iex>Ultraviolet.Color.HSL.new({60, 0.0, 0.5})\n    {:ok, %Ultraviolet.Color.HSL{h: 60, s: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.HSL.html#new/1"},{"type":"function","title":"Ultraviolet.Color.HSL.new/3","doc":"Generates a new HSL color object\n\n    iex>Ultraviolet.Color.HSL.new(60, 0.0, 0.5)\n    {:ok, %Ultraviolet.Color.HSL{h: 60, s: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.HSL.html#new/3"},{"type":"function","title":"Ultraviolet.Color.HSL.new/4","doc":"Generates a new HSL color object\n\n    iex>Ultraviolet.Color.HSL.new(60, 0.0, 0.5, 0.5)\n    {:ok, %Ultraviolet.Color.HSL{h: 60, s: 0.0, l: 0.5, a: 0.5}}","ref":"Ultraviolet.Color.HSL.html#new/4"},{"type":"function","title":"Ultraviolet.Color.HSL.to_rgb/1","doc":"Converts from HSL to an RGB Color object\n\nconversion taken from https://wikipedia.org/wiki/HSL_color_space","ref":"Ultraviolet.Color.HSL.html#to_rgb/1"},{"type":"function","title":"Options - Ultraviolet.Color.HSL.to_rgb/1","doc":"- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.HSL.html#to_rgb/1-options"},{"type":"function","title":"Ultraviolet.Color.HSL.to_rgb/2","doc":"","ref":"Ultraviolet.Color.HSL.html#to_rgb/2"},{"type":"type","title":"Ultraviolet.Color.HSL.t/0","doc":"Defines the channels in an HSL color.","ref":"Ultraviolet.Color.HSL.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.HSV","doc":"Functions for working in the HSV color space","ref":"Ultraviolet.Color.HSV.html"},{"type":"function","title":"Ultraviolet.Color.HSV.from_rgb/2","doc":"Converts a Color to HSV","ref":"Ultraviolet.Color.HSV.html#from_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.HSV.from_rgb/2","doc":"- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.HSV.html#from_rgb/2-options"},{"type":"function","title":"Ultraviolet.Color.HSV.new/1","doc":"Generates a new HSV color object\n\n    iex>Ultraviolet.Color.HSV.new({60, 0.0, 0.5})\n    {:ok, %Ultraviolet.Color.HSV{h: 60, s: 0.0, v: 0.5}}","ref":"Ultraviolet.Color.HSV.html#new/1"},{"type":"function","title":"Ultraviolet.Color.HSV.new/3","doc":"Generates a new HSV color object\n\n    iex>Ultraviolet.Color.HSV.new(60, 0.0, 0.5)\n    {:ok, %Ultraviolet.Color.HSV{h: 60, s: 0.0, v: 0.5}}","ref":"Ultraviolet.Color.HSV.html#new/3"},{"type":"function","title":"Ultraviolet.Color.HSV.new/4","doc":"Generates a new HSV color object\n\n    iex>Ultraviolet.Color.HSV.new(60, 0.0, 0.5, 0.5)\n    {:ok, %Ultraviolet.Color.HSV{h: 60, s: 0.0, v: 0.5, a: 0.5}}","ref":"Ultraviolet.Color.HSV.html#new/4"},{"type":"function","title":"Ultraviolet.Color.HSV.to_rgb/1","doc":"Converts from HSV to an RGB Color object","ref":"Ultraviolet.Color.HSV.html#to_rgb/1"},{"type":"function","title":"Options - Ultraviolet.Color.HSV.to_rgb/1","doc":"- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.HSV.html#to_rgb/1-options"},{"type":"function","title":"Ultraviolet.Color.HSV.to_rgb/2","doc":"","ref":"Ultraviolet.Color.HSV.html#to_rgb/2"},{"type":"type","title":"Ultraviolet.Color.HSV.t/0","doc":"Defines the channels in an HSV / HSB color.","ref":"Ultraviolet.Color.HSV.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.LCH","doc":"Functions for working in the LCH / HCL colorspace.","ref":"Ultraviolet.Color.LCH.html"},{"type":"function","title":"Ultraviolet.Color.LCH.from_rgb/2","doc":"Converts from an RGB Color struct to a LCH struct.","ref":"Ultraviolet.Color.LCH.html#from_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.LCH.from_rgb/2","doc":"- `:reference`: the CIE Lab white reference point. Default: `:d65`\n- `:round`: an integer if rounding L, a*, and b* channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `2`","ref":"Ultraviolet.Color.LCH.html#from_rgb/2-options"},{"type":"function","title":"Ultraviolet.Color.LCH.new/1","doc":"Generates a new LCH color\n\n    iex>Ultraviolet.Color.LCH.new({0.5, 0.0, 60})\n    {:ok, %Ultraviolet.Color.LCH{h: 60, c: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.LCH.html#new/1"},{"type":"function","title":"Ultraviolet.Color.LCH.new/3","doc":"Generates a new LCH color\n\n    iex>Ultraviolet.Color.LCH.new(0.5, 0.0, 60)\n    {:ok, %Ultraviolet.Color.LCH{h: 60, c: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.LCH.html#new/3"},{"type":"function","title":"Ultraviolet.Color.LCH.new/4","doc":"Generates a new LCH color\n\n    iex>Ultraviolet.Color.LCH.new(0.5, 0.0, 60, 0.5)\n    {:ok, %Ultraviolet.Color.LCH{h: 60, c: 0.0, l: 0.5, a: 0.5}}","ref":"Ultraviolet.Color.LCH.html#new/4"},{"type":"function","title":"Ultraviolet.Color.LCH.to_rgb/2","doc":"Converts from LCH to an RGB Color struct","ref":"Ultraviolet.Color.LCH.html#to_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.LCH.to_rgb/2","doc":"- `:reference`: the CIE Lab [white reference point](`t:Ultraviolet.Color.Lab.white_point/0`). Default: `:d65`\n- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.LCH.html#to_rgb/2-options"},{"type":"type","title":"Ultraviolet.Color.LCH.t/0","doc":"Defines the channels in a LCH color.","ref":"Ultraviolet.Color.LCH.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.Lab","doc":"Functions for working in the CIE Lab color space.\n\nTo calculate the lightness value of a color (`L`), the CIE Lab color space\nuses a reference white point. This reference white point defines what is\nconsidered to be \"white\" in the color space. By default Ultraviolet uses the\nD65 reference point.\n\nPossible reference points are:\n\n- `:d50`: Represents the color temperature of daylight at 5000K.\n- `:d55`: Represents mid-morning or mid-afternoon daylight at 5500K.\n- `:d65`: Represents average daylight at 6500K (*default*)\n- `:a`: Represents the color temperature of a typical incandescent light bulb at approximately 2856K.\n- `:b`: Represents noon daylight with a color temperature of approximately 4874K.\n- `:c`: Represents average or north sky daylight; it's a theoretical construct, not often used in practical applications.\n- `:f2`: Represents cool white fluorescent light.\n- `:f7`: This is a broad-band fluorescent light source with a color temperature of approximately 6500K.\n- `:f11`: This is a narrow tri-band fluorescent light source with a color temperature of approximately 4000K.\n- `:e`: Represents an equal energy white point, where all wavelengths in the visible spectrum are equally represented.\n- `:icc`","ref":"Ultraviolet.Color.Lab.html"},{"type":"function","title":"Ultraviolet.Color.Lab.from_rgb/2","doc":"Converts from an RGB Color struct to a Lab struct.","ref":"Ultraviolet.Color.Lab.html#from_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.Lab.from_rgb/2","doc":"- `:reference`: the CIE Lab white reference point. Default: `:d65`\n  - `:round`: an integer if rounding L, a*, and b* channel values to N decimal\n    places is desired; if no rounding is desired, pass `false`. Default: `2`","ref":"Ultraviolet.Color.Lab.html#from_rgb/2-options"},{"type":"function","title":"Ultraviolet.Color.Lab.new/1","doc":"Generates a new CIE Lab color.\n\n    iex>Ultraviolet.Color.Lab.new({65.49, 64.24, -10.65})\n    {:ok, %Ultraviolet.Color.Lab{l_: 65.49, a_: 64.24, b_: -10.65}}","ref":"Ultraviolet.Color.Lab.html#new/1"},{"type":"function","title":"Ultraviolet.Color.Lab.new/3","doc":"Generates a new CIE Lab color.\n\n    iex>Ultraviolet.Color.Lab.new(65.49, 64.24, -10.65)\n    {:ok, %Ultraviolet.Color.Lab{l_: 65.49, a_: 64.24, b_: -10.65}}","ref":"Ultraviolet.Color.Lab.html#new/3"},{"type":"function","title":"Ultraviolet.Color.Lab.new/4","doc":"Generates a new CIE Lab color.\n\n    iex>Ultraviolet.Color.Lab.new(65.49, 64.24, -10.65, 0.5)\n    {:ok, %Ultraviolet.Color.Lab{l_: 65.49, a_: 64.24, b_: -10.65, a: 0.5}}","ref":"Ultraviolet.Color.Lab.html#new/4"},{"type":"function","title":"Ultraviolet.Color.Lab.to_rgb/2","doc":"Converts from CIE Lab to sRGB","ref":"Ultraviolet.Color.Lab.html#to_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.Lab.to_rgb/2","doc":"- `:reference`: the CIE Lab [white reference point](`t:white_point/0`). Default: `:d65`\n- `:round`: an integer if rounding r, g, and b channel values to N decimal\n  places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.Lab.html#to_rgb/2-options"},{"type":"type","title":"Ultraviolet.Color.Lab.t/0","doc":"Defines the channels in a Lab color.","ref":"Ultraviolet.Color.Lab.html#t:t/0"},{"type":"type","title":"Ultraviolet.Color.Lab.white_point/0","doc":"","ref":"Ultraviolet.Color.Lab.html#t:white_point/0"},{"type":"module","title":"Ultraviolet.Color.OKLCH","doc":"Functions for wokring with the OKLCH color space.\n\nOKLCH is to LCH as OKLab is to Lab.\n\nUses the `:d65` reference illuminant.","ref":"Ultraviolet.Color.OKLCH.html"},{"type":"function","title":"Ultraviolet.Color.OKLCH.from_rgb/2","doc":"Converts from an RGB Color struct to a LCH struct.","ref":"Ultraviolet.Color.OKLCH.html#from_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.OKLCH.from_rgb/2","doc":"- `:round`: an integer if rounding L, a*, and b* channel values to N decimal\n    places is desired; if no rounding is desired, pass `false`. Default: `2`","ref":"Ultraviolet.Color.OKLCH.html#from_rgb/2-options"},{"type":"function","title":"Ultraviolet.Color.OKLCH.new/1","doc":"Generates a new LCH color\n\n    iex>Ultraviolet.Color.LCH.new({0.5, 0.0, 60})\n    {:ok, %Ultraviolet.Color.LCH{h: 60, c: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.OKLCH.html#new/1"},{"type":"function","title":"Ultraviolet.Color.OKLCH.new/3","doc":"Generates a new OKLCH color object\n\n    iex>Ultraviolet.Color.OKLCH.new(0.5, 0.0, 60)\n    {:ok, %Ultraviolet.Color.OKLCH{h: 60, c: 0.0, l: 0.5}}","ref":"Ultraviolet.Color.OKLCH.html#new/3"},{"type":"function","title":"Ultraviolet.Color.OKLCH.new/4","doc":"Generates a new OKLCH color object\n\n    iex>Ultraviolet.Color.OKLCH.new(0.5, 0.0, 60, 0.5)\n    {:ok, %Ultraviolet.Color.OKLCH{h: 60, c: 0.0, l: 0.5, a: 0.5}}","ref":"Ultraviolet.Color.OKLCH.html#new/4"},{"type":"function","title":"Ultraviolet.Color.OKLCH.to_rgb/2","doc":"Converts from OKLCH to sRGB","ref":"Ultraviolet.Color.OKLCH.html#to_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.OKLCH.to_rgb/2","doc":"- `:round`: an integer if rounding r, g, and b channel values to N decimal\n    places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.OKLCH.html#to_rgb/2-options"},{"type":"type","title":"Ultraviolet.Color.OKLCH.t/0","doc":"Defines the channels in an OKLCH color.","ref":"Ultraviolet.Color.OKLCH.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.OKLab","doc":"Functions for working with the\n[OKLab](https://bottosson.github.io/posts/oklab/) color space.\n\nUses the `:d65` reference illuminant.","ref":"Ultraviolet.Color.OKLab.html"},{"type":"function","title":"Ultraviolet.Color.OKLab.from_rgb/2","doc":"Converts from sRGB to OKLab.","ref":"Ultraviolet.Color.OKLab.html#from_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.OKLab.from_rgb/2","doc":"- `:round`: an integer if rounding L, a*, and b* channel values to N decimal\n    places is desired; if no rounding is desired, pass `false`. Default: `2`","ref":"Ultraviolet.Color.OKLab.html#from_rgb/2-options"},{"type":"function","title":"Ultraviolet.Color.OKLab.new/1","doc":"Generates a new OKLab color\n\n    iex>Ultraviolet.Color.OKLab.new({0.5, 0.0, 0.0})\n    {:ok, %Ultraviolet.Color.OKLab{l_: 0.5, a_: 0.0, b_: 0.0}}","ref":"Ultraviolet.Color.OKLab.html#new/1"},{"type":"function","title":"Ultraviolet.Color.OKLab.new/3","doc":"Generates a new OKLab color\n\n    iex>Ultraviolet.Color.OKLab.new(0.5, 0.0, 0.0)\n    {:ok, %Ultraviolet.Color.OKLab{l_: 0.5, a_: 0.0, b_: 0.0}}","ref":"Ultraviolet.Color.OKLab.html#new/3"},{"type":"function","title":"Ultraviolet.Color.OKLab.new/4","doc":"Generates a new OKLab color\n\n    iex>Ultraviolet.Color.OKLab.new(0.5, 0.0, 0.0, 0.5)\n    {:ok, %Ultraviolet.Color.OKLab{l_: 0.5, a_: 0.0, b_: 0.0, a: 0.5}}","ref":"Ultraviolet.Color.OKLab.html#new/4"},{"type":"function","title":"Ultraviolet.Color.OKLab.to_rgb/2","doc":"Converts from OKLab to sRGB.","ref":"Ultraviolet.Color.OKLab.html#to_rgb/2"},{"type":"function","title":"Options - Ultraviolet.Color.OKLab.to_rgb/2","doc":"- `:round`: an integer if rounding r, g, and b channel values to N decimal\n    places is desired; if no rounding is desired, pass `false`. Default: `0`","ref":"Ultraviolet.Color.OKLab.html#to_rgb/2-options"},{"type":"type","title":"Ultraviolet.Color.OKLab.t/0","doc":"Defines the channels in an OKLab color.","ref":"Ultraviolet.Color.OKLab.html#t:t/0"},{"type":"module","title":"Ultraviolet.Color.Temperature","doc":"Functions for mapping temperatures to colors.\n\nBased on Neil Bartlett's\n[implementation](https://github.com/neilbartlett/color-temperature)\n\nSee `Ultraviolet.temperature/1` for examples.","ref":"Ultraviolet.Color.Temperature.html"},{"type":"function","title":"Ultraviolet.Color.Temperature.from_rgb/2","doc":"Converts a color into an approximate temperature.","ref":"Ultraviolet.Color.Temperature.html#from_rgb/2"},{"type":"function","title":"Ultraviolet.Color.Temperature.to_rgb/2","doc":"Converts a temperature to an approximate color.\n\nThe effective temperature range goes from 0 to about 30,000K.","ref":"Ultraviolet.Color.Temperature.html#to_rgb/2"},{"type":"extras","title":"README","doc":"# Ultraviolet\n\n[![hex.pm badge](https://img.shields.io/badge/Package%20on%20hex.pm-informational)](https://hex.pm/packages/ultraviolet)\n[![Documentation badge](https://img.shields.io/badge/Documentation-ff69b4)][docs]\n[![Coverage Status](https://coveralls.io/repos/github/dcrck/ultraviolet/badge.svg?branch=main)](https://coveralls.io/github/dcrck/ultraviolet?branch=main)\n\n[Online Documentation][docs].\n\nAn Elixir color manipulation library designed to work like\n[`chroma-js`](https://github.com/gka/chroma.js). It may not have full parity\nwith `chroma-js`, but it includes most of the common operations and features.","ref":"readme.html"},{"type":"extras","title":"Quick Start - README","doc":"Here are a few things `Ultraviolet` can do:\n\n- read colors from a wide range of inputs\n- analyze and manipulate colors\n- convert colors into a wide range of formats\n- linear, bezier, and custom interpolation in different color spaces\n\nHere's an example of a simple read / manipulate / output chain\n\n```elixir\n{:ok, color} = Ultraviolet.new(\"pink\")\n\ncolor\n|> Ultraviolet.Color.darken!()\n|> Ultraviolet.Color.saturate!(2)\n|> Ultraviolet.Color.hex()\n#=> \"#ff6d93\"\n```\n\nAside from that, `Ultraviolet` can help you **generate nice colors** using\nvarious methods. These colors can be used, for example, as a color palette for\nmaps or data visualization.\n\n```elixir\n{:ok, scale} = Ultraviolet.scale([\"#fafa6e\", \"#2a4858\"], space: :lch)\ncolors = Ultraviolet.Scale.take(scale, 6)\n```\n\nThere's a lot more to offer; the [documentation][docs] contains more examples\nof how to use `Ultraviolet`.","ref":"readme.html#quick-start"},{"type":"extras","title":"Installation - README","doc":"You can install `ultraviolet` by adding it to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ultraviolet, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - README","doc":"Copyright 2024 Derek Meer\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the “Software”), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n\n[docs]: https://hexdocs.pm/ultraviolet","ref":"readme.html#license"},{"type":"extras","title":"License","doc":"Copyright 2024 Derek Meer\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of\nthis software and associated documentation files (the “Software”), to deal in\nthe Software without restriction, including without limitation the rights to\nuse, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of\nthe Software, and to permit persons to whom the Software is furnished to do so,\nsubject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS\nFOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER\nIN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN\nCONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.\n\n------------------------------------------------------\n\nAlthough this code does not include any source code from chroma.js, some of\nthe algorithms have been directly translated from JavaScript to Elixir. It\nfeels appropriate to include the license for chroma.js below:\n\nCopyright (c) 2011-2024, Gregor Aisch\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n1. Redistributions of source code must retain the above copyright notice, this\n   list of conditions and the following disclaimer.\n\n2. Redistributions in binary form must reproduce the above copyright notice,\n   this list of conditions and the following disclaimer in the documentation\n   and/or other materials provided with the distribution.\n\n3. The name Gregor Aisch may not be used to endorse or promote products\n   derived from this software without specific prior written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\nAND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL GREGOR AISCH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,\nINDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,\nBUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,\nDATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY\nOF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING\nNEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,\nEVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n-------------------------------------------------------\n\nUltraviolet includes colors from colorbrewer2.org, which are released under\nthe following license:\n\nCopyright (c) 2002 Cynthia Brewer, Mark Harrower,\nand The Pennsylvania State University.\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\nhttp://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing,\nsoftware distributed under the License is distributed on an\n\"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,\neither express or implied. See the License for the specific\nlanguage governing permissions and limitations under the License.\n\n------------------------------------------------------\n\nNamed colors are taken from X11 Color Names.\nhttp://www.w3.org/TR/css3-color/#svg-color","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}